Citing Verde
============

This is research software **made by scientists**. Citations help us justify the effort
that goes into building and maintaining this project.

If you used Verde in your research, please consider citing our paper:

    Uieda, L. (2018). Verde: Processing and gridding spatial data using Green's
    functions. Journal of Open Source Software, 3(29), 957. doi:10.21105/joss.00957

This is an open-access publication and can be freely downloaded from
https://doi.org/10.21105/joss.00957

Here is a Bibtex entry to make things easier if you're using Latex:

.. code:: bibtex

    @article{uieda2018,
      title = {{Verde}: {Processing} and gridding spatial data using {Green's} functions},
      author = {Uieda, Leonardo},
      year = {2018},
      journal = {Journal of Open Source Software},
      volume = {3},
      number = {29},
      pages = {957},
      issn = {2475-9066},
      doi = {10.21105/joss.00957},
    }
